bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift C ## 13. Aventiure
___________________________________________________ #### Auentv wie Chriemh' mit ir man zer hochgecite fvr
| ### Alle> ir vnmvze die lazen wir nv sin ### vn– sagen iv wie Chriemh' vn– ovch ir magedin ### zer hochgecite fvoren von Nibelunge lant ### nie getrugen moere so manic herlich gewant ### Vil der leitschrine man schicte zv den wegen ### do reit mit sinen frivndin Sivrit der degen ### vn– ovch div kuniginne vf hoher frevden wan ### ir frevde mvse leider mit grozem iamer sit zergan
###### 787 | ### Da heime si do liezen ir beider kindelin ### beliben in ir landen daz mvos et also sin ### von ir hovereise erstunden starchiv ser ### vater vn– mvoter gesach daz kindel nimmer mer
###### 788 | ### Da mite reit der herre der kunic Sigemunt ### solder der getrowen wie ez im nach der stunt ### zer hochgecite ergienge ern het ir niht gesehen ### ia chunde im in der werlde leider nimmer geschehen
| ### Boten man fvr sande die div mære sagten dar ### do reit ovch in engegene mit maniger liehten schar ### vil der gvten degene der Guntheres man ### der wirt sich gegen den gesten sere vlizen began
###### 790 | ### Er gie zv Prvnhilde da er si sizzen vant ### wie enpfie et ivch min swester do ir chomet in daz lant ### sam svlt ovch ir enpfahen daz Sivrides wip ### daz tvn ih sprach div frowe <daz> hat verschuldet wol ir lip
###### 791 | ### Do sprach aber Gunther si choment vns morgen frvo ### nv ir si welt enpfahen da grifet balde zvo ### daz wir ir in der buorge niht erbiten hie ### mir chom in manigen ziten so rehte lieber geste nie
###### 792 | ### Ir meide vn– ovch ir frowen die hiez si do zehant ### svchen gvtiv chleider die besten die man vant ### die si wol mit eren vor gesten mohten tragen ### wie gern si daz tæten daz mac man lihte gesagen
| ### Ovch ilten in do dienen die Guntheres man ### alle sine degene der wirt zv sich gewan ### da reit div kuniginne mit ir frowen mite ### gegen den lieben gesten al nach friuntlichem site
###### 794 | ### Mit wie getanen eren man die geste enpfie ### si dvhte daz frov Chriemh' Prunh' nie ### so rehte wol enpfienge in Burgonden lant ### die si ê niene gesahen den wart vil hoher mvot erchant
###### 795 | ### Nv was ovch komen Sivrit mit den sinen man ### man sach die helde wenden wider vn– dan ### des veldes allenthalben mit vngefvgen scharn ### dringen vn– stovben chunde niemen da bewarn
###### 796 | ### Do der wirt des landes Sivriden sach ### vn– ovch Sigemunden wie gutlicher sprach ### nv sit mir groze willechomen vn– al den vriunden min ### der iwer hovereise svln wir hochgemvte sin
| ### Nv lone iv got sprach Sigemunt der ere gernder man ### sit daz ivch min svn Sivrit ze friunde gewan ### do rieten [30v]mine sinne daz ich ivch solde sehn ### do sprach der wirt zem gaste nv ist mir liebe dran geschehn
###### 798 | ### Sivrit wart enpfangen als im daz wol gezam ### mit vil grozen eren im was da niemen gram ### des half mit grozen zvhten Giselher vn– Gernot ### ich wæne man ez gesten nie so minneklich erbot
###### 799 | ### Do nahten zvo zein ander der zweier kunige wip ### da wart vil sætil lære maniger schonen frowen lip ### wart von rechen <handen> erhaben vf daz gras ### die frowen gerne dienten waz der mit vnmuozen was
###### 800 | ### Do giengen zvo zein ander div minneklichen wip ### des was in grozen freuden uil maniges rechen lip ### daz ir beider grvzen so schone wart getan ### do sahe man vil der degene mit zvhten bi den frowen stan
###### 801 | ### Daz herrenlich gesinde sich uiengen bi der hant ### in zvhten groze nigen des man vil da vant ### vn– chussen minnekliche von frowen wolgetan ### daz was liep ze sehene den <kunigen> vn– ir beider man
| ### Sine biten da niht langer si riten zv der stat ### der wirt den sinen gesten daz wol erzeigen bat ### daz man si gerne sæhe in Buregonden lant ### vil manigen pvneyz richen man vor den iuncfrowen vant
###### 803 | ### Vzer Tronege Hagene vn– ovch Ortewin ### daz si gewaltich wæren daz wart da vil wol schin ### swaz si gebieten wolden daz torste niemen lan ### von in wart michel dienest den edeln gesten getan
###### 804 | ### Vil schilde hort man schellen da zem burgetor ### von stichen vn– von stozen vil lange habt der vor ### der wirt mit sinen gesten e daz si komen drin ### ia gie in div stunde mit vil grozen vreuden hin
###### 805 | ### Fvr den palas richen mit frevden si do riten ### vil manigen pfellel spæhen rich vn– wol gesniten ### sach man vber sætele den frowen wolgetan ### allenthalben hangen do chomen Guntheres man
###### 806 | ### Die hiezen si do fvren balde an ir gemach ### vnder wilen blichen man Prunh' sach ### an frowen Chriemh' div schone was genvoch ### ir varwe gegen dem glanze den schin vil herlichen trvoch
| ### Allenthalben schallen ze <Wormez> in der stat ### hort manz gesinde der wirt den marschalch bat ### Danchwart Hagenen brvder er solde ir selbe pflegen ### do begunder daz gesinde harte gvtliche legen
###### 808 | ### Da vze vn– oech dar inne spisen man si lie ### ez enwart deheiner geste baz gepflegen nie ### allez daz si wolden des was man in bereit ### der chunich was so riche daz da wart niemen niht verseit
###### 809 | ### Man dient in friuntliche vn– ane allen haz ### der wirt do ze tische mit sinnen gesten saz ### do mvse sizzen Sivrit als er ê het getan ### mit im gie ze tische vil manic wætlicher man
###### 810 | ### Einlife hundert rechen an dem ringe sin ### mit im zem ezzen sazen Prunh' div kunigin ### gedaht daz eigen holde niht richer chunden we[31r]sen ### si was im noch so wæge daz si in gerne lie genesn
| ### Alda der wirt mit frevden mit sinen gesten saz ### vil der richen chleider wart von wine naz ### da die schenchen solden zv den tischen gan ### da wart vil voller dienest mit grozem willen getan
###### 812 | ### So man ze hochgeciten lange hat gepflegen ### frowen vn– meide hiez man schone legen ### von swannen si dar chomen der wirt in willen trvoch ### mit vil grozen zvhten man gab in allen genvoch
###### 813 | ### Do div naht het ende vn– daz der tac erschein ### vz den leitschrinen vil manic edel stein ### erluht in gvter wæte die rvorte frowen hant ### do wart dar fvr geschuochet vil manic herlich gewant
###### 814 | ### E daz ez vol ertagete do chomen fvr den sal ### vil ritter vn– knehte do hvop sich aber schal ### vor einer frvo messe die man dem kunige sanch ### da riten iunge degene daz mans in mvse sagen danch
###### 815 | ### Lvot un– ane maze manic pusvon erdoz ### von trumben vn– floyten wart der schal so groz ### daz Wormez div vil wite dar nach vil lvte erschal ### die hochgemvten degene zen rossen chomen vber al
###### 816 | ### Do hvop sich in dem lande harte hoh ein spil ### von manigem gvten degene der was da harte vil ### den ir tvmbiv hercen rieten hohen mvot ### der sah man vnder schilde manigen zieren rechen gvot
###### 817 | ### In div venster sazen div herlichen wip ### vn– vil der schonen mægede gezieret was ir lip ### si sahen kurcewile von manigem chvnem man ### der wirt mit sinen degenen selbe riten da began
###### 818 | ### Also vergie ir wile div dvhte si niht lanc ### do horte man zem tvome vil maniger glocken chlanch ### do chomen in die more die frowen riten dan ### den edeln kuniginnen volget vil manic chune man
###### 819 | ### Si stunden vor dem mvnster nider vf daz gras ### Prunh' ir gesten dannoch vil wæge was ### si giengen vnder chrone in daz mvnster wit ### div liebe wart sit gescheiden daz frumte groezlicher nit
###### 820 | ### Do si gehorten messe si fuoren wider dan ### mit vil grozen zvhten man sach si sider gan ### ze tische minnekliche ir frevde nie gelach ### da zer hochgecite vnz an den einliften tac
###### 821 | ### Do gedaht div kuniginne ine mac niht langer dagn ### swie ich daz gefuge Chriemh' mvz mir sagen ### warumbe vns also lange denn zins versezzen hat ### ir man derst unser eigen der vrage han ich cheinen rat
###### 822 | ### Svs warte si der wile als ez der tivfel riet ### die frovde vn– ovch die hohgecit mit iamer si do schiet ### daz ir lach amme hercen ze lieht ez mvse chomen ### des wart in manigen landen von ir iamers vil vernomen

<<< Übersicht <<< vorige Seite nächste Seite >>>